@@ -23,14 +23,7 @@ class Function(Proxy):
         return self._decorate_or_call(*args, **kw)
     
     def __get__(self, obj, cls):
-        if obj:
-            # access within instance (e.g., Foo().bar)
-            # wrap the current functor with Function1
-            # no matter the current functor is Function1 or Function2
-            return BoundedFunction(self, obj)
-        else:
-            # access in static way (e.g., Foo.bar)
-            return self
+        return Method(self, obj, cls)
     
     def __str__(self):
         return '<Function %s.%s>' % (self._func.__module__, self.__name__)
@@ -120,8 +113,13 @@ def PartialFunction(func, init_args=(), init_kw=None, call_args=(), call_kw=None
             self.optional_params = tuple([(k, v) for (k, v) in self.optional_params if k not in call_kw])
     return _PartialFunction
         
-def BoundedFunction(func, instance):
-    return PartialFunction(Function, call_args=(instance,))(func)
+def Method(func, obj, cls):
+    call_args = (obj,) if obj is not None else ()
+    method = PartialFunction(Function, call_args=call_args)(func)
+    method.im_class = cls
+    method.im_func = method.__func__ = func
+    method.im_self = method.__self__ = obj
+    return method
 
 def _is_bound_method(func):
     '''
@@ -138,10 +136,7 @@ def _is_bound_method(func):
     >>> _is_bound_method(Foo().bar)
     True
     '''
-    try:
-        return func.__self__ is not None
-    except:
-        return False
+    return hasattr(func, '__self__') and func.__self__ is not None
 
 if __name__ == '__main__':
     doctest.testmod()
